# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'entitlement/entitlement'
require 'puppet_x/vulnerability/selection'
require 'puppet_x/vulnerability/config'
require 'deep_merge'

begin
  Entitlement::Entitlement.entitled?('vulnerability#facts#cve_list')

  Facter.add('cve_list') do
    confine do
      kernel = Facter.value(:kernel)
      case kernel
      when 'Linux'
        required_files = ['/usr/local/etc/grype_yaml.tpl', '/usr/local/bin/grype', '/usr/local/etc/vulnerability.conf']
      when 'windows'
        required_files = ['c:/vulnerability/etc/grype_yaml.tpl', 'c:/vulnerability/bin/grype.exe', 'c:/vulnerability/etc/vulnerability.conf']
      else
        fail "'#{kernel}' not (yet) supported."
      end
      required_files.all? { |f| File.exist?(f) }
    end
    confine :kernel do |value|
      %w[linux windows].include?(value)
    end

    setcode do
      extend Vulnerability::Selection
      extend Vulnerability::Config
      if Gem::Version.new(Facter.version) <= Gem::Version.new('4.0.19')
        Puppet.warn_once(:old_facter_version, 'vulnerability::facts::facter_version',
                         'Current facter version doesn\'t support fact caching. Vulnerability scan will be done on every pass. Please update to facter version 4.0.19 or higher.')
      end

      directories = config_data[:directories]
      level       = config_data[:level]
      config      = "#{grype_root}/etc/grype.yaml"
      template    = "#{grype_root}/etc/grype_yaml.tpl"

      cve_list = {}
      Puppet.debug "Found directories #{directories.join(',')} for scanning."
      directories.each do |directory|
        Puppet.debug "Scanning '#{directory}' for vulnerabilities"
        vulnerabilities = Facter::Core::Execution.execute("#{grype_binary} -c #{config} dir:#{directory} -o template -t #{template}", :timeout => 7200)
        data = YAML.safe_load(vulnerabilities)&.reduce({}, :deep_merge) unless vulnerabilities.empty?
        data ||= {}
        cve_list = cve_list.deep_merge(data)
      end
      level_selection(cve_list, level)
    end
  end
rescue StandardError
  Puppet.warn_once(:no_vulnerability_entilement, 'vulnerability::facts::cve_list', 'vulnerability module not entitled on this node; Skipping vulnerability scanning')
end
