#
# vulnerability::remediate
#
# @summary Let Puppet remediate the selected vulnerabilies.
# Based on the provided `cve_list` (through hiera), the module constructs a puppet class name. This class will be entered into the Puppet catalog and **should** remediate the selected CVE.
# 
# The construction of the remediation class name exists of two steps:
# 
# 1) Puppet will do a hiera lookup for the name: `vulnerability::remediate::$cve` where $ce is the name of the specified CVE. If this lookup is succesfull, Puppet will use this value as the name of the Puppet class. Using this mechanism, you can specify any class you would like.
# 2) If step 1 does not lead to a class name, Puppet will create a class name based on the value of the `remediation_module` name. The class will be: `$remediation_module::$cve`
# 
# When the selected class does not exist, Puppet will issue a message when applying the catalog.
#
# @param [Array[String[1]]] cve_list
#    An array of Strings describing the CVE's you want Puppet to remediate.
#    For every specified CVE, Puppet constructs a puppet class name. This class is entered into the Puppet catalog and **should** remediate the specified vulnerability.
#
# @param [String[1]] remediation_module
#    The name that is used as base module name for the generation of a remediation class.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class vulnerability::remediate (
  Array[String[1]]  $cve_list,
  String[1]         $remediation_module
) {
  $cve_list.each  |$cve| {
    $lookup_name = "vulnerability::remediate::${cve}"
    $lookup_value = lookup($lookup_name, Optional[String[1]], 'first', undef)
    $klass_name = if $lookup_value != undef {
      $lookup_value
    } else {
      "${remediation_module}::${cve}"
    }
    if defined($klass_name) {
      require $klass_name
    } else {
      notify { "Remediation class ${klass_name} not defined. Skipping remediation of CVE ${cve}.":
        loglevel => 'err',
        withpath => false,
      }
    }
  }
}
